# mars_clock
A package for converting mission sols to local and terrestrial times

The calculations here are based on [Piqueux et al. (2015) Icarus 251,
332](https://ui.adsabs.harvard.edu/abs/2015Icar..251..332P/abstract).
